@@ -359,6 +359,9 @@ INVALIDPARAMETERVALUE_ISPERSISTENCE = 'InvalidParameterValue.IsPersistence'
 # Isps 参数错误。
 INVALIDPARAMETERVALUE_ISPS = 'InvalidParameterValue.Isps'
 
+# ItemId 错误。
+INVALIDPARAMETERVALUE_ITEMID = 'InvalidParameterValue.ItemId'
+
 # 参数值错误：打点信息内容过长。
 INVALIDPARAMETERVALUE_KEYFRAMEDESCCONTENTTOOLONG = 'InvalidParameterValue.KeyFrameDescContentTooLong'
 
@@ -659,6 +662,9 @@ LIMITEXCEEDED_KEYFRAMEDESCCOUNTREACHMAX = 'LimitExceeded.KeyFrameDescCountReachM
 # 播放列表长度太大。
 LIMITEXCEEDED_PLAYLIST = 'LimitExceeded.PlayList'
 
+# 播单列表长度超过上限。
+LIMITEXCEEDED_ROUNDPLAYLIST = 'LimitExceeded.RoundPlaylist'
+
 # 超过播单总数限制。
 LIMITEXCEEDED_ROUNDPLAYS = 'LimitExceeded.RoundPlays'
 
